@@ -17,3 +17,6 @@ from .nnp_detect import NNPDetect
 from .pyaaware import _SEDConfig
 from .pyaaware import _SED
 from .sed import SED
+
+from .pyaaware import _Predict
+from .predict import Predict
