@@ -64,13 +64,14 @@ class ForwardTransform:
         has_channels = xt.ndim == 2
         samples = xt.shape[0]
         frames = int(np.ceil(samples / self.R) + (self.N - self.R) / self.R)
-        x = np.pad(xt, ((0, frames * self.R - samples), (0, 0)), 'constant')
 
         if has_channels:
             channels = xt.shape[1]
+            x = np.pad(xt, ((0, frames * self.R - samples), (0, 0)), 'constant')
             yf = np.empty((self._bins, channels, frames), dtype=np.csingle)
         else:
             channels = 1
+            x = np.pad(xt, (0, frames * self.R - samples), 'constant')
             yf = np.empty((self._bins, frames), dtype=np.csingle)
 
         for channel in range(channels):
@@ -96,5 +97,8 @@ class ForwardTransform:
         self._ft.execute(xt, yf)
         return yf
 
-    def energy(self, x: np.ndarray) -> np.single:
-        return self._ft.energy(x)
+    def energy_t(self, x: np.ndarray) -> np.single:
+        return self._ft.energy_t(x)
+
+    def energy_f(self, x: np.ndarray) -> np.ndarray:
+        return self._ft.energy_f(x)
